@@ -441,6 +441,7 @@ type MachineService struct {
 	InternalPort             int                        `json:"internal_port,omitempty" toml:"internal_port,omitempty"`
 	Autostop                 *bool                      `json:"autostop,omitempty"`
 	Autostart                *bool                      `json:"autostart,omitempty"`
+	MinMachinesRunning       *int                       `json:"min_machines_running,omitempty"`
 	Ports                    []MachinePort              `json:"ports,omitempty" toml:"ports,omitempty"`
 	Checks                   []MachineCheck             `json:"checks,omitempty" toml:"checks,omitempty"`
 	Concurrency              *MachineServiceConcurrency `json:"concurrency,omitempty" toml:"concurrency"`
@@ -581,3 +582,21 @@ type MachineExecResponse struct {
 	StdOut   string `json:"stdout,omitempty"`
 	StdErr   string `json:"stderr,omitempty"`
 }
+
+type MachinePsResponse []ProcessStat
+
+type ProcessStat struct {
+	Pid           int32          `json:"pid"`
+	Stime         uint64         `json:"stime"`
+	Rtime         uint64         `json:"rtime"`
+	Command       string         `json:"command"`
+	Directory     string         `json:"directory"`
+	Cpu           uint64         `json:"cpu"`
+	Rss           uint64         `json:"rss"`
+	ListenSockets []ListenSocket `json:"listen_sockets"`
+}
+
+type ListenSocket struct {
+	Proto   string `json:"proto"`
+	Address string `json:"address"`
+}
