@@ -27,6 +27,11 @@ type Secret struct {
 	Generate func() (string, error)
 }
 
+type MergeConfigStruct struct {
+	Name      string
+	Temporary bool
+}
+
 type SourceInfo struct {
 	Family                       string
 	Version                      string
@@ -57,6 +62,7 @@ type SourceInfo struct {
 	Callback                     func(srcInfo *SourceInfo, options map[string]bool) error
 	HttpCheckPath                string
 	ConsoleCommand               string
+	MergeConfig                  *MergeConfigStruct
 }
 
 type SourceFile struct {
@@ -68,8 +74,9 @@ type Static struct {
 	UrlPrefix string `toml:"url_prefix" json:"url_prefix"`
 }
 type Volume struct {
-	Source      string `toml:"source" json:"source"`
-	Destination string `toml:"destination" json:"destination"`
+	Source      string   `toml:"source" json:"source,omitempty"`
+	Destination string   `toml:"destination" json:"destination,omitempty"`
+	Processes   []string `json:"processes,omitempty" toml:"processes,omitempty"`
 }
 type ScannerConfig struct {
 	Mode         string
